aboutsummaryrefslogtreecommitdiff
path: root/src/include
diff options
context:
space:
mode:
Diffstat (limited to 'src/include')
-rw-r--r--src/include/donau_json_lib.h12
-rw-r--r--src/include/donau_service.h10
2 files changed, 16 insertions, 6 deletions
diff --git a/src/include/donau_json_lib.h b/src/include/donau_json_lib.h
index efadfa5..1f243e4 100644
--- a/src/include/donau_json_lib.h
+++ b/src/include/donau_json_lib.h
@@ -72,6 +72,18 @@ DONAU_JSON_spec_blinded_donation_identifier (
/**
+ * Generate line in parser specification for donation unit signature.
+ *
+ * @param field name of the field
+ * @param[out] sig the signature to initialize
+ * @return corresponding field spec
+ */
+struct GNUNET_JSON_Specification
+DONAU_JSON_spec_blinded_donation_unit_sig (const char *field,
+ struct DONAU_BlindedDonationUnitSignature *sig);
+
+
+/**
* Generate packer instruction for a JSON field of type
* unsigned integer.
*
diff --git a/src/include/donau_service.h b/src/include/donau_service.h
index 213d84f..7701f30 100644
--- a/src/include/donau_service.h
+++ b/src/include/donau_service.h
@@ -470,17 +470,16 @@ struct DONAU_BatchIssueResponse
struct
{
- uint32_t num_donau_sigs;
-
/**
* Blind signature provided by the donau
*/
- const struct TALER_BlindedDonationUnitSignature *donau_sigs;
+ struct DONAU_BlindedDonationUnitSignature *donau_sigs;
/**
* total amount over all donation receipts of a year specified by the request.
*/
- const struct TALER_Amount total_amount;
+ struct TALER_Amount issued_amount;
} ok;
@@ -535,7 +534,6 @@ DONAU_charity_issue_receipt (
struct GNUNET_CURL_Context *ctx,
const char *url,
const struct DONAU_CharityPrivateKeyP *charity_priv,
- const struct DONAU_CharityPublicKeyP *charity_pub,
const uint64_t charity_id,
const uint64_t year,
const size_t num_bkp,
@@ -470,17 +470,16 @@ struct DONAU_BatchIssueResponse
/**
- * total amount over all donation receipts of a year specified by the request.
+ * total issued amount over all donation receipts of a donation specified
+ * by the request (confirmation).
*/